function eqs=chemeqs(st,cn)
% chemeqs  - Shows the chemical equations defined by a stoichiometric array
% function eqs=chemeqs(st,cn)
% Argument List:
% Argument    Gives
%   st      the matrix of stoichiometric
%           coefficients 
%   cn      array of compound names
% chemeqs runs chemeq once for 
%    each column of st.
% The output in eqs is a list
% of the chemical equations.
% Ex. stoic=[-1 -3 2];
%     cnms=cgrp('N2','H2','NH3');
%     chemeqs(stoic,cnms)
% OKB
eqs = '';
sst=size(st);
for i=1:sst(1)
   eqs=mgrp(eqs,chemeq(st(i,:),cn));
end
